@@ -25,16 +25,17 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
+
 #include "gtkmain.h"
 #include "gtkmarshalers.h"
 #include "gtkplug.h"
+#include "gtkintl.h"
 #include "gtkprivate.h"
 #include "gtkplugprivate.h"
 
 #include "gtkalias.h"
 
-static void            gtk_plug_class_init            (GtkPlugClass     *klass);
-static void            gtk_plug_init                  (GtkPlug          *plug);
 static void            gtk_plug_finalize              (GObject          *object);
 static void            gtk_plug_realize               (GtkWidget        *widget);
 static void            gtk_plug_unrealize             (GtkWidget        *widget);
@@ -55,7 +56,6 @@ static gboolean        gtk_plug_focus                 (GtkWidget        *widget,
 static void            gtk_plug_check_resize          (GtkContainer     *container);
 static void            gtk_plug_keys_changed          (GtkWindow        *window);
 
-static GtkWindowClass *parent_class = NULL;
 static GtkBinClass *bin_class = NULL;
 
 typedef struct
@@ -71,32 +71,7 @@ enum {
 
 static guint plug_signals[LAST_SIGNAL] = { 0 };
 
-GType
-gtk_plug_get_type (void)
-{
-  static GType plug_type = 0;
-
-  if (!plug_type)
-    {
-      static const GTypeInfo plug_info =
-      {
-	sizeof (GtkPlugClass),
-	NULL,           /* base_init */
-	NULL,           /* base_finalize */
-	(GClassInitFunc) gtk_plug_class_init,
-	NULL,           /* class_finalize */
-	NULL,           /* class_data */
-	sizeof (GtkPlug),
-	16,             /* n_preallocs */
-	(GInstanceInitFunc) gtk_plug_init,
-      };
-
-      plug_type = g_type_register_static (GTK_TYPE_WINDOW, "GtkPlug",
-					  &plug_info, 0);
-    }
-
-  return plug_type;
-}
+G_DEFINE_TYPE (GtkPlug, gtk_plug, GTK_TYPE_WINDOW)
 
 static void
 gtk_plug_class_init (GtkPlugClass *class)
@@ -106,7 +81,6 @@ gtk_plug_class_init (GtkPlugClass *class)
   GtkWindowClass *window_class = (GtkWindowClass *)class;
   GtkContainerClass *container_class = (GtkContainerClass *)class;
 
-  parent_class = g_type_class_peek_parent (class);
   bin_class = g_type_class_peek (GTK_TYPE_BIN);
 
   gobject_class->finalize = gtk_plug_finalize;
@@ -131,7 +105,7 @@ gtk_plug_class_init (GtkPlugClass *class)
   window_class->keys_changed = gtk_plug_keys_changed;
 
   plug_signals[EMBEDDED] =
-    g_signal_new ("embedded",
+    g_signal_new (I_("embedded"),
 		  G_OBJECT_CLASS_TYPE (class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (GtkPlugClass, embedded),
@@ -228,23 +202,23 @@ gtk_plug_get_id (GtkPlug *plug)
  **/
 void
 _gtk_plug_add_to_socket (GtkPlug   *plug,
-			 GtkSocket *socket)
+			 GtkSocket *socket_)
 {
   GtkWidget *widget;
   gint w, h;
   
   g_return_if_fail (GTK_IS_PLUG (plug));
-  g_return_if_fail (GTK_IS_SOCKET (socket));
-  g_return_if_fail (GTK_WIDGET_REALIZED (socket));
+  g_return_if_fail (GTK_IS_SOCKET (socket_));
+  g_return_if_fail (GTK_WIDGET_REALIZED (socket_));
 
   widget = GTK_WIDGET (plug);
 
   gtk_plug_set_is_child (plug, TRUE);
   plug->same_app = TRUE;
-  socket->same_app = TRUE;
-  socket->plug_widget = widget;
+  socket_->same_app = TRUE;
+  socket_->plug_widget = widget;
 
-  plug->socket_window = GTK_WIDGET (socket)->window;
+  plug->socket_window = GTK_WIDGET (socket_)->window;
 
   if (GTK_WIDGET_REALIZED (widget))
     {
@@ -252,9 +226,9 @@ _gtk_plug_add_to_socket (GtkPlug   *plug,
       gdk_window_reparent (widget->window, plug->socket_window, -w, -h);
     }
 
-  gtk_widget_set_parent (widget, GTK_WIDGET (socket));
+  gtk_widget_set_parent (widget, GTK_WIDGET (socket_));
 
-  g_signal_emit_by_name (socket, "plug_added");
+  g_signal_emit_by_name (socket_, "plug_added");
 }
 
 /**
@@ -286,20 +260,20 @@ _gtk_plug_send_delete_event (GtkWidget *widget)
 /**
  * _gtk_plug_remove_from_socket:
  * @plug: a #GtkPlug
- * @socket: a #GtkSocket
+ * @socket_: a #GtkSocket
  * 
  * Removes a plug from a socket within the same application.
  **/
 void
 _gtk_plug_remove_from_socket (GtkPlug   *plug,
-			      GtkSocket *socket)
+			      GtkSocket *socket_)
 {
   GtkWidget *widget;
   gboolean result;
   gboolean widget_was_visible;
 
   g_return_if_fail (GTK_IS_PLUG (plug));
-  g_return_if_fail (GTK_IS_SOCKET (socket));
+  g_return_if_fail (GTK_IS_SOCKET (socket_));
   g_return_if_fail (GTK_WIDGET_REALIZED (plug));
 
   widget = GTK_WIDGET (plug);
@@ -308,7 +282,7 @@ _gtk_plug_remove_from_socket (GtkPlug   *plug,
     return;
 
   g_object_ref (plug);
-  g_object_ref (socket);
+  g_object_ref (socket_);
 
   widget_was_visible = GTK_WIDGET_VISIBLE (plug);
   
@@ -320,33 +294,33 @@ _gtk_plug_remove_from_socket (GtkPlug   *plug,
   gtk_widget_unparent (GTK_WIDGET (plug));
   GTK_PRIVATE_UNSET_FLAG (plug, GTK_IN_REPARENT);
   
-  socket->plug_widget = NULL;
-  if (socket->plug_window != NULL)
+  socket_->plug_widget = NULL;
+  if (socket_->plug_window != NULL)
     {
-      g_object_unref (socket->plug_window);
-      socket->plug_window = NULL;
+      g_object_unref (socket_->plug_window);
+      socket_->plug_window = NULL;
     }
   
-  socket->same_app = FALSE;
+  socket_->same_app = FALSE;
 
   plug->same_app = FALSE;
   plug->socket_window = NULL;
 
   gtk_plug_set_is_child (plug, FALSE);
 		    
-  g_signal_emit_by_name (socket, "plug_removed", &result);
+  g_signal_emit_by_name (socket_, "plug_removed", &result);
   if (!result)
-    gtk_widget_destroy (GTK_WIDGET (socket));
+    gtk_widget_destroy (GTK_WIDGET (socket_));
 
   if (widget->window)
     _gtk_plug_send_delete_event (widget);
 
   g_object_unref (plug);
 
-  if (widget_was_visible && GTK_WIDGET_VISIBLE (socket))
-    gtk_widget_queue_resize (GTK_WIDGET (socket));
+  if (widget_was_visible && GTK_WIDGET_VISIBLE (socket_))
+    gtk_widget_queue_resize (GTK_WIDGET (socket_));
 
-  g_object_unref (socket);
+  g_object_unref (socket_);
 }
 
 /**
@@ -458,7 +432,7 @@ gtk_plug_finalize (GObject *object)
       plug->grabbed_keys = NULL;
     }
   
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (gtk_plug_parent_class)->finalize (object);
 }
 
 static void
@@ -486,8 +460,8 @@ gtk_plug_unrealize (GtkWidget *widget)
       g_object_unref (plug->modality_group);
     }
   
-  if (GTK_WIDGET_CLASS (parent_class)->unrealize)
-    (* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
+  if (GTK_WIDGET_CLASS (gtk_plug_parent_class)->unrealize)
+    (* GTK_WIDGET_CLASS (gtk_plug_parent_class)->unrealize) (widget);
 }
 
 static void
@@ -576,7 +550,7 @@ static void
 gtk_plug_show (GtkWidget *widget)
 {
   if (GTK_WIDGET_TOPLEVEL (widget))
-    GTK_WIDGET_CLASS (parent_class)->show (widget);
+    GTK_WIDGET_CLASS (gtk_plug_parent_class)->show (widget);
   else
     GTK_WIDGET_CLASS (bin_class)->show (widget);
 }
@@ -585,7 +559,7 @@ static void
 gtk_plug_hide (GtkWidget *widget)
 {
   if (GTK_WIDGET_TOPLEVEL (widget))
-    GTK_WIDGET_CLASS (parent_class)->hide (widget);
+    GTK_WIDGET_CLASS (gtk_plug_parent_class)->hide (widget);
   else
     GTK_WIDGET_CLASS (bin_class)->hide (widget);
 }
@@ -646,7 +620,7 @@ gtk_plug_size_allocate (GtkWidget     *widget,
 			GtkAllocation *allocation)
 {
   if (GTK_WIDGET_TOPLEVEL (widget))
-    GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
+    GTK_WIDGET_CLASS (gtk_plug_parent_class)->size_allocate (widget, allocation);
   else
     {
       GtkBin *bin = GTK_BIN (widget);
@@ -679,7 +653,7 @@ gtk_plug_key_press_event (GtkWidget   *widget,
 			  GdkEventKey *event)
 {
   if (GTK_WIDGET_TOPLEVEL (widget))
-    return GTK_WIDGET_CLASS (parent_class)->key_press_event (widget, event);
+    return GTK_WIDGET_CLASS (gtk_plug_parent_class)->key_press_event (widget, event);
   else
     return FALSE;
 }
@@ -701,7 +675,7 @@ gtk_plug_set_focus (GtkWindow *window,
 {
   GtkPlug *plug = GTK_PLUG (window);
 
-  GTK_WINDOW_CLASS (parent_class)->set_focus (window, focus);
+  GTK_WINDOW_CLASS (gtk_plug_parent_class)->set_focus (window, focus);
   
   /* Ask for focus from embedder
    */
@@ -799,7 +773,7 @@ keys_foreach (GtkWindow      *window,
 	      gpointer        data)
 {
   GHashTable *new_grabbed_keys = data;
-  GrabbedKey *key = g_new (GrabbedKey, 1);
+  GrabbedKey *key = g_slice_new (GrabbedKey);
 
   key->accelerator_key = keyval;
   key->accelerator_mods = modifiers;
@@ -807,13 +781,19 @@ keys_foreach (GtkWindow      *window,
   g_hash_table_replace (new_grabbed_keys, key, key);
 }
 
+static void
+grabbed_key_free (gpointer data)
+{
+  g_slice_free (GrabbedKey, data);
+}
+
 static void
 gtk_plug_keys_changed (GtkWindow *window)
 {
   GHashTable *new_grabbed_keys, *old_grabbed_keys;
   GtkPlug *plug = GTK_PLUG (window);
 
-  new_grabbed_keys = g_hash_table_new_full (grabbed_key_hash, grabbed_key_equal, (GDestroyNotify)g_free, NULL);
+  new_grabbed_keys = g_hash_table_new_full (grabbed_key_hash, grabbed_key_equal, (GDestroyNotify)grabbed_key_free, NULL);
   _gtk_window_keys_foreach (window, keys_foreach, new_grabbed_keys);
 
   if (plug->socket_window)
@@ -878,7 +858,7 @@ static void
 gtk_plug_check_resize (GtkContainer *container)
 {
   if (GTK_WIDGET_TOPLEVEL (container))
-    GTK_CONTAINER_CLASS (parent_class)->check_resize (container);
+    GTK_CONTAINER_CLASS (gtk_plug_parent_class)->check_resize (container);
   else
     GTK_CONTAINER_CLASS (bin_class)->check_resize (container);
 }
